@@ -1,5 +1,10 @@
 context("nnet")
 
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
+
 skip_if_not_installed("nnet")
 library(nnet)
 
@@ -19,5 +24,5 @@ test_that("tidy.multinom", {
 test_that("glance.multinom", {
   gl <- glance(fit)
   check_glance_outputs(gl)
-  check_dims(gl, expected_cols = 3)
+  check_dims(gl, expected_cols = 4)
 })
